@@ -1,8 +1,8 @@
-Seminaive=function(data,y.col,coords.col,covar,covar.col,copred,cov.model="exponential",thetaini,fix.nugget=T,nugget,kappa=0,cons,MaxIter,cc,cutoff,trend){
+Seminaive=function(data,y.col,coords.col,covar,covar.col,copred,cov.model="exponential",thetaini,fix.nugget=T,nugget,kappa=0,cons,MaxIter,cc,trend){
 
   if(!is.data.frame(data) & !is.numeric(data)) stop("data must be a data.frame or numeric matrix")
   if(!is.data.frame(data)) data=as.data.frame(data)
-  if(!is.numeric(cutoff)) stop ("cutoff mus be a numeric vector")
+  #if(!is.numeric(cutoff)) stop ("cutoff mus be a numeric vector")
   if(!is.numeric(thetaini)) stop ("thetaini must be a numeric vector thetaini=(sigma2,phi)")
   if(length(which(thetaini<0))>0) stop("all initials values for the covariance structure must be in [0,Inf)")
   if(length(thetaini)!=2) stop("thetaini must contains the initials values for sigma2 and phi")
@@ -12,8 +12,8 @@ Seminaive=function(data,y.col,coords.col,covar,covar.col,copred,cov.model="expon
   if(nugget<0) stop("nugget must be a real number in [0,Inf)")
   if(!is.logical(fix.nugget)) stop("fix.nugget must be TRUE or FALSE.")
   if(!is.logical(covar)) stop(" covar must be TRUE or FALSE.")
-  if(nrow(data)!=nrow(cc)) stop ("data and cc does not have the same number of lines")
-  if(length(which(cc==1))< length(cutoff)) stop("Detections limits not coincide with the number of censored observations")
+  if(nrow(data)!=nrow(as.matrix(cc))) stop ("data and cc does not have the same number of lines")
+  #if(length(which(cc==1))< length(cutoff)) stop("Detections limits not coincide with the number of censored observations")
   if (trend!='cte'& trend!='1st' & trend!="2nd" & class(trend)!= "formula") stop('trend is not valid (see trend.spatial from geoR)')
   if(!is.numeric(y.col)) stop("a correct column for y (response) must be specified")
   if((y.col%%1)!=0) stop("a correct column for y (response) must be specified")
@@ -41,21 +41,22 @@ gneiting, gneiting.matern, pure.nugget')
   if(sum(is.na(data)) > 0) stop("There are some NA values in data")
   if(sum(is.na(cc)) > 0) stop("There are some NA values in cc")
   if(sum(is.na(copred)) > 0) stop("There are some NA values in copred")
-  if(sum(is.na(cutoff)) > 0) stop("There are some NA values in cutoff")
+  #if(sum(is.na(cutoff)) > 0) stop("There are some NA values in cutoff")
 
   ######Not data
   y = data[,y.col]
   coords = data[,coords.col]
-  
-  if((length(y) == 0) | (length(cc) == 0)|(length(coords) == 0)|(length(copred) == 0)|(length(cutoff) == 0)){
+
+  if((length(y) == 0) | (length(cc) == 0)|(length(coords) == 0)|(length(copred) == 0))
+     {
     stop("All parameters must be provided")}
 
   if(covar==F){
-    if(class(trend)=="formula") stop("trend must be cte,1stor 2nd when covar=F")
+    if(class(trend)=="formula") stop("trend must be cte,1st or 2nd when covar=F")
   }
 
 
-  out=suppressWarnings(seminaive(data=data,y.col=y.col,covar=covar,coords.col=coords.col,covar.col=covar.col,cov.model=cov.model,thetaini=thetaini,fix.nugget=fix.nugget,nugget=nugget,kappa=kappa,cons=cons,MaxIter=MaxIter,cc=cc,cutof=cutoff,copred=copred,trend=trend))
+  out=suppressWarnings(seminaive(data=data,y.col=y.col,covar=covar,coords.col=coords.col,covar.col=covar.col,cov.model=cov.model,thetaini=thetaini,fix.nugget=fix.nugget,nugget=nugget,kappa=kappa,cons=cons,MaxIter=MaxIter,cc=cc,copred=copred,trend=trend))
 
 
 
@@ -130,4 +131,4 @@ mu = X*beta"
 
   return(out)
 
-}
\ No newline at end of file
+}
